@@ -1,9 +1,11 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Generic, Iterator, List, TypeVar
+from typing import Any, Generic, Iterator, List, TypeVar
 
 from modupipe.base import Condition
+from modupipe.loader import Loader
+from modupipe.queue import Queue, QueuePutStrategy
 
 Input = TypeVar("Input")
 Output = TypeVar("Output")
@@ -15,14 +17,14 @@ class Mapper(ABC, Generic[Input, Output]):
     def map(self, items: Iterator[Input]) -> Iterator[Output]:
         pass
 
-    def with_next(self, next: Mapper[Output, NextOutput]) -> Mapper[Input, NextOutput]:
-        return Next(self, next)
-
     def __add__(self, next: Mapper[Output, NextOutput]) -> Mapper[Input, NextOutput]:
-        return self.with_next(next)
+        return ChainedMapper(self, next)
 
 
-class Next(Mapper[Input, NextOutput], Generic[Input, Output, NextOutput]):
+IdentityMapper = Mapper[Input, Input]
+
+
+class ChainedMapper(Mapper[Input, NextOutput], Generic[Input, Output, NextOutput]):
     def __init__(
         self, mapper: Mapper[Input, Output], next: Mapper[Output, NextOutput]
     ) -> None:
@@ -34,7 +36,7 @@ class Next(Mapper[Input, NextOutput], Generic[Input, Output, NextOutput]):
         return self.next.map(output)
 
 
-class Filter(Mapper[Input, Input], Generic[Input]):
+class Filter(IdentityMapper[Input]):
     def __init__(self, condition: Condition[Input]) -> None:
         self.condition = condition
 
@@ -44,13 +46,20 @@ class Filter(Mapper[Input, Input], Generic[Input]):
                 yield item
 
 
-class ToString(Mapper[Input, str], Generic[Input]):
+class ToString(Mapper[Input, str]):
     def map(self, items: Iterator[Input]) -> Iterator[str]:
         for item in items:
             yield str(item)
 
 
-class Buffer(Mapper[Input, List[Input]], Generic[Input]):
+class Print(IdentityMapper[Input]):
+    def map(self, items: Iterator[Input]) -> Iterator[Input]:
+        for item in items:
+            print(item)
+            yield item
+
+
+class Buffer(Mapper[Input, List[Input]]):
     def __init__(self, size: int) -> None:
         self.size = size
         self.buffer: List[Input] = []
@@ -62,3 +71,33 @@ class Buffer(Mapper[Input, List[Input]], Generic[Input]):
             if len(self.buffer) >= self.size:
                 yield self.buffer
                 self.buffer = []
+
+
+class PutToQueue(IdentityMapper[Input]):
+    def __init__(self, queue: Queue[Input], strategy: QueuePutStrategy) -> None:
+        self.queue = queue
+        self.strategy = strategy
+
+    def map(self, items: Iterator[Input]) -> Iterator[Input]:
+        for item in items:
+            self.strategy.put(self.queue, item)
+            yield item
+
+
+class PushTo(IdentityMapper[Input]):
+    def __init__(self, loader: Loader[Input, Any]) -> None:
+        self.loader = loader
+
+    def map(self, items: Iterator[Input]) -> Iterator[Input]:
+        for item in items:
+            self.loader.load(item)
+            yield item
+
+
+class PushToAndMap(Mapper[Input, Output]):
+    def __init__(self, loader: Loader[Input, Output]) -> None:
+        self.loader = loader
+
+    def map(self, items: Iterator[Input]) -> Iterator[Output]:
+        for item in items:
+            yield self.loader.load(item)
