@@ -2,15 +2,23 @@ import multiprocessing
 import queue
 from abc import ABC, abstractmethod
 from typing import Generic, TypeVar, Union
+from uuid import uuid4
 
 T = TypeVar("T")
 
 
 class Queue(Generic[T]):
     def __init__(
-        self, queue: Union["queue.Queue[T]", "multiprocessing.Queue[T]"]
+        self,
+        queue: Union["queue.Queue[T]", "multiprocessing.Queue[T]"],
+        name: str = str(uuid4()),
     ) -> None:
         self.queue = queue
+        self._name = name
+
+    @property
+    def name(self) -> str:
+        return self._name
 
     def get(self, *args, **kwargs) -> T:
         return self.queue.get(*args, **kwargs)
@@ -18,10 +26,13 @@ class Queue(Generic[T]):
     def put(self, item: T, *args, **kwargs) -> None:
         self.queue.put(item, *args, **kwargs)
 
+    def __len__(self) -> int:
+        return self.queue.qsize()
+
 
 class QueuePutStrategy(ABC, Generic[T]):
     @abstractmethod
-    def put(self, queue: Queue[T], input: T):
+    def put(self, queue: Queue[T], item: T):
         pass
 
 
@@ -29,13 +40,13 @@ class PutBlocking(QueuePutStrategy[T]):
     def __init__(self, timeout: int = None) -> None:
         self.timeout = timeout
 
-    def put(self, queue: Queue[T], input: T):
-        queue.put(input, block=True, timeout=self.timeout)
+    def put(self, queue: Queue[T], item: T):
+        queue.put(item, block=True, timeout=self.timeout)
 
 
 class PutNonBlocking(QueuePutStrategy[T]):
-    def put(self, queue: Queue[T], input: T):
-        queue.put(input, block=False)
+    def put(self, queue: Queue[T], item: T):
+        queue.put(item, block=False)
 
 
 class QueueGetStrategy(ABC, Generic[T]):
